@@ -5,6 +5,8 @@ Copyright (c) 2006-2019 sqlmap developers (http://sqlmap.org/)
 See the file 'LICENSE' for copying permission
 """
 
+from __future__ import print_function
+
 try:
     import sys
 
@@ -51,6 +53,7 @@ try:
     from lib.core.data import kb
     from lib.core.common import unhandledExceptionMessage
     from lib.core.common import MKSTEMP_PREFIX
+    from lib.core.common import setColor
     from lib.core.exception import SqlmapBaseException
     from lib.core.exception import SqlmapShellQuitException
     from lib.core.exception import SqlmapSilentQuitException
@@ -188,10 +191,10 @@ def main():
         raise SystemExit
 
     except KeyboardInterrupt:
-        print
+        print()
 
     except EOFError:
-        print
+        print()
 
         errMsg = "exit"
         logger.error(errMsg)
@@ -200,7 +203,7 @@ def main():
         pass
 
     except:
-        print
+        print()
         errMsg = unhandledExceptionMessage()
         excMsg = traceback.format_exc()
         valid = checkIntegrity()
@@ -210,13 +213,13 @@ def main():
             errMsg += "You should retrieve the latest development version from official GitHub "
             errMsg += "repository at '%s'" % GIT_PAGE
             logger.critical(errMsg)
-            print
+            print()
             dataToStdout(excMsg)
             raise SystemExit
 
         elif any(_ in excMsg for _ in ("tamper/", "waf/")):
             logger.critical(errMsg)
-            print
+            print()
             dataToStdout(excMsg)
             raise SystemExit
 
@@ -225,16 +228,21 @@ def main():
             logger.critical(errMsg)
             raise SystemExit
 
-        elif "MemoryError" in excMsg:
+        elif any(_ in excMsg for _ in ("MemoryError", "Cannot allocate memory")):
             errMsg = "memory exhaustion detected"
             logger.critical(errMsg)
             raise SystemExit
 
-        elif any(_ in excMsg for _ in ("No space left", "Disk quota exceeded")):
+        elif any(_ in excMsg for _ in ("No space left", "Disk quota exceeded", "Disk full while accessing")):
             errMsg = "no space left on output device"
             logger.critical(errMsg)
             raise SystemExit
 
+        elif any(_ in excMsg for _ in ("The paging file is too small",)):
+            errMsg = "no space left for paging file"
+            logger.critical(errMsg)
+            raise SystemExit
+
         elif all(_ in excMsg for _ in ("No such file", "_'", "self.get_prog_name()")):
             errMsg = "corrupted installation detected ('%s'). " % excMsg.strip().split('\n')[-1]
             errMsg += "You should retrieve the latest development version from official GitHub "
@@ -332,8 +340,7 @@ def main():
             logger.critical("%s\n%s" % (errMsg, excMsg))
         else:
             logger.critical(errMsg)
-            kb.stickyLevel = logging.CRITICAL
-            dataToStdout(excMsg)
+            dataToStdout("%s\n" % setColor(excMsg.strip(), level=logging.CRITICAL))
             createGithubIssue(errMsg, excMsg)
 
     finally:
